@@ -122,7 +122,7 @@ class Desktop(MethodsInterface):
                     # поместить данные во временный tarfile
                     remove_files = []
                     tf = tempfile.TemporaryFile()
-                    for fn in (".calculate", ".dmrc", ".face", ".face.icon"):
+                    for fn in listDirectory(userDir, fullPath=False):
                         full_fn = path.join(userDir, fn)
                         if path.lexists(full_fn):
                             with tarfile.open(fileobj=tf, mode='w:') as tarf:
